#!/usr/bin/perl -w

######################### LAST UPDATED: Jan, 2003 #########################
 
# interestOne.pl version 0.1

###########################################################################
#
# This program converts `interest' data as in the SOURCE file into 
# Senseval-1 data format. The output is placed in the DESTINATION file.
# It prints the number of instances converted to Senseval-1 and thereby
# Senseval-2 data format.
# Exactly one blank line is placed between instances.
# Morphological forms of interest which may constitute the head word are 
# assumed to be:
#
#	interest, interested, interests and interesting
#
# The program converts `{' and `}' characters in the data to their 
# corresponding character reference format - `&lcub;' and `&rcub;'.
# The consecutive `==' and `$$' symbols are eliminated.
# Every sentence is placed within <s> and </s> tags.
# All square braces are placed in angular braces as they are not contextual 
# information. For example:
#	[ last/JJ month/NN ] -----> <[> last/JJ month/NN <]>
#
# USAGE :  interestOne.pl [OPTIONS] DESTINATION SOURCE
#
###########################################################################

###########################################################################
#
# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###########################################################################

############################ START OF PROGRAM #############################

use Getopt::Long;

# Check if any options specified
GetOptions("help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help ) {
    &help();
    exit; }

# Check if any options specified
GetOptions("help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help ) {
    &help();
    exit; }

# Check if command line options have been provided
# If not print usage information
if ( $#ARGV < 1 ) {
    &usage();
    exit; }

$opfl = shift();
$inpfl = shift();

if(-f $opfl) {
    print "Destination file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y") {
        print "Overwriting the file.\n"; }
    else {
        exit; } }

# Open files
open(OP,">$opfl");
open(INP,"<$inpfl");

# BEGIN PROCESSING

# Read lines from the file - line by line
while($ln = <INP>) {
    # Eliminate the consecutive `==' and `$$' symbols
    if ($ln =~ /^\s*\$\$\s*$/) {
	next; }
    if ($ln =~ /===*/) {
	$ln =~ s/(===*)//g; }

    # Ignore line if blank
    if($ln =~ /^\s*$/) { next; }

    # Convert `{' and `}' to `&lcub;' and `&rcub;'
    $ln =~s/\{/&lcub\;/g;
    $ln =~s/\}/&rcub\;/g;

    # Place square braces within angular braces
    # CHANGE
    # $ln =~s/([\[\]])/<$1>/g;
    $ln =~s/\[/<&lsqb\;>/g;
    $ln =~s/\]/<&rsqb\;>/g;
  
    # Print Instance ID
    $instanceNo ++;
    print OP "int$instanceNo\n";

    # Place the sentence within <s> and </s> tags
    $ln =~ s/^\s*(.*[^\s])\s*$/<s> $1 <\/s>/;
 
    # tag the head word line; possible forms line, lines
    if(!($ln =~ s/([^a-zA-Z])(interest(ed|ing|s)?)_(\d)/$1 <tag \"interest_$4\">$2<\/> /)) {
    # if(!($ln =~ s/([^a-zA-Z])(interest(ed|ing|s)?)_(\d)(\/[^a-z\s]+)/$1 <tag \"interest_$4\">$2$5<\/> /)) {
    	print "$instanceNo : Line without head word\n";
    	exit; }

    print OP "$ln\n\n"; }

print "$inpfl converted. $instanceNo instances in all.\n";

#################### Subroutine to print help message #####################

sub help {
    print "\nUsage: interestOne.pl [OPTIONS] DESTINATION SOURCE\n\n";
    print "This program converts interest data as in the SOURCE file into Senseval-1 data format. The output is placed in the DESTINATION file.\n\n";
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n\n"; }

sub usage {
    print "\nUsage: interestOne.pl [OPTIONS] DESTINATION SOURCE\n\n"; 
    AskHelp(); }
# Message describing way to get help
sub AskHelp {
    print "Type interestOne.pl --help for help.\n\n"; }

############################### END PROGRAM ###############################
