#! /usr/bin/perl -w

#### LAST UPDATED: May, 2003 ####
# xmlise-pos.pl version 0.1

###########################################################################
#
# This program places all the part of speech tags in the SOURCE file 
# within angular braces. The output is placed in DESTINATION. For example:
# 	Jack/NNP ---> Jack <NNP>
#
# USAGE :  xmlise-pos.pl [OPTIONS] DESTINATION SOURCE
#
###########################################################################

# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# START OF PROGRAM
use Getopt::Long;

# Check if any options specified
GetOptions("help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help ) {
    &help();
    exit; }

# Check if commandline options have been provided
# If not print usage information
if ( $#ARGV < 1 ) {
    &usage();
    exit;}

$opfl = shift();
$inpfl = shift();

if(-f $opfl) {  
    print "Destination file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y") {
	print "Overwriting the file.\n"; }
    else{
	exit; } }
 
# Open the various files
open(INP,"<$inpfl");
open(OP,">$opfl");

$incontext = 0;
# Read lines from input file
while($ln = <INP>) {
    # Set variable based on whether line part of context or not
    if($ln =~ /^\s*<context>\s*$/) {
	$incontext = 1;
	print OP $ln;
	next; }
    if($ln =~ /^\s*<\/context>\s*$/) {
	$incontext = 0; 
	print OP $ln;
	next; }
    
    # Process only if line part of context
    if($incontext){
	# Ignore blank lines
	if($ln =~ /^\s*$/){
	    next;}

	# xmlise the pos tags
	$ln =~ s/(<\/head>)\s*\/([^a-z\s]+)/$1 <$2>/g; 
	$ln =~ s/([^\s])\/([^a-z\s]+)/$1 <$2>/g; }

    print OP $ln; }

# Subroutine to print help message
sub help{
    print "\nUsage: xmlise-pos.pl [OPTIONS] DESTINATION SOURCE\n\n"; 
    print "This program places all the part of speech tags in the SOURCE file within angular braces. The output is placed in DESTINATION. For example: Jack/NNP ---> Jack <NNP> \n\n";
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n\n";}

sub usage{
    print "\nUsage: xmlise-pos.pl [OPTIONS] DESTINATION SOURCE\n\n"; 
    AskHelp();}
# Message desscribing way to get help
sub AskHelp{
    print "Type xmlise-pos.pl --help for help.\n";}
